SizingDimensions

Struct SizingDimensions 

pub struct SizingDimensions {
    pub min: PositiveFinite,
    pub preferred: PreferredSize,
    pub max: Positive,
}
Represents the sizing information for a UI element used while calculating layout.

Fields

min: PositiveFinitepreferred: PreferredSizemax: Positive

Implementations

Source

impl SizingDimensions

pub fn is_fixed(&self) -> bool

True if the sizing is fixed and layout calculations will not change it.

pub fn is_growable(&self) -> bool

True if the sizing is growable and can expand to fill available space.

pub fn is_shrinkable(&self) -> bool

True if the sizing is shrinkable and can be reduced in size when overflowing its container.

pub fn get_grow_factor(&self) -> f64

Returns the growth factor for the dimension.

pub fn clamped(&self, value: f64) -> f64

Returns the dimension value clamped between min and max.

let sized = SizingDimensions {
    min: PositiveFinite::new(100.0).unwrap(),
    preferred: PreferredSize::Fixed(PositiveFinite::new(200.0).unwrap()),
    max: Positive::new(300.0).unwrap(),
};
assert_eq!(sized.clamped(250.0), 250.0);
assert_eq!(sized.clamped(50.0), 100.0);
assert_eq!(sized.clamped(350.0), 300.0);

assert_eq!(sized.clamped(f64::NAN), 100.0); // NaN defaults to min
assert_eq!(sized.clamped(f64::INFINITY), 300.0);
assert_eq!(sized.clamped(f64::NEG_INFINITY), 100.0);
pub fn max(&self) -> f64

pub fn min(&self) -> f64